class Hi:
    def __init__(self):
        print("preparing to say hi...")

    def say_hi(self):
        print("Hi you! ")
